start

# PHP

Many PHP programs make use of a localisable string array. The toolkit supports the full localisation of such files with php2po and po2php.

## Example

The localisable string arrays appear like this:

    <?php
    $string['name'] = 'value'

## Conformance

Our format support allows:

- PHP escaping (both for single and double quoted strings)
- Multiline entries
- Various layouts of the id:

    $string['name']
    $string[name]
    $string[ 'name' ]

- PHP array syntax for localisation (since > 1.6.0):

    $lang = array(
       'name' => 'value',
       'name2' => 'value2',
    );

## Non-Conformance

The following are not yet supported:

- herdoc and nowdoc are not managed